==> jc-1.4.0.tar.gz: javax/rmi/CORBA/Stub.h <==
// public abstract class javax.rmi.CORBA.Stub

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5219dfd5835e78ba javax_rmi_CORBA_ObjectImpl
// @dep_class cc968e93a57cbcb6 javax_rmi_CORBA_Stub

// header file dependencies
// @dep_header javax_rmi_CORBA_ObjectImpl

#include "javax/rmi/CORBA/ObjectImpl.h"

#ifndef _JC_javax_rmi_CORBA_Stub_H_
#define _JC_javax_rmi_CORBA_Stub_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_rmi_CORBA_StubDelegate$object;
struct _jc_javax_rmi_ORB$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_Stub$sub_refs	_jc_javax_rmi_CORBA_Stub$sub_refs;
typedef struct _jc_javax_rmi_CORBA_Stub$sub_nonrefs	_jc_javax_rmi_CORBA_Stub$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_Stub$refs	_jc_javax_rmi_CORBA_Stub$refs;
typedef struct _jc_javax_rmi_CORBA_Stub$nonrefs	_jc_javax_rmi_CORBA_Stub$nonrefs;
typedef struct _jc_javax_rmi_CORBA_Stub$object	_jc_javax_rmi_CORBA_Stub$object;

typedef struct _jc_javax_rmi_CORBA_Stub$fields_struct	_jc_javax_rmi_CORBA_Stub$fields_struct;
typedef const struct _jc_javax_rmi_CORBA_Stub$vmethods	_jc_javax_rmi_CORBA_Stub$vmethods;
typedef const struct _jc_javax_rmi_CORBA_Stub$vtable	_jc_javax_rmi_CORBA_Stub$vtable;
typedef const struct _jc_javax_rmi_CORBA_Stub$vtype	_jc_javax_rmi_CORBA_Stub$vtype;

// Class fields structure
struct _jc_javax_rmi_CORBA_Stub$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_rmi_CORBA_Stub$fields_struct _jc_javax_rmi_CORBA_Stub$class_fields;

// Constructors
extern void _jc_javax_rmi_CORBA_Stub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *);

// Virtual methods
extern void _jc_javax_rmi_CORBA_Stub$method$connect$841f9bfd39e4d76b(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_javax_rmi_ORB$object *);
extern jboolean _jc_javax_rmi_CORBA_Stub$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_javax_rmi_CORBA_Stub$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *);
extern void _jc_javax_rmi_CORBA_Stub$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectInputStream$object *);
extern struct _jc_java_lang_String$object *_jc_javax_rmi_CORBA_Stub$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *);
extern void _jc_javax_rmi_CORBA_Stub$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$connect$841f9bfd39e4d76b;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_javax_rmi_CORBA_Stub$vmethods {
	void	(*connect$841f9bfd39e4d76b)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_javax_rmi_ORB$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *);
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectInputStream$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *);
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectOutputStream$object *);
};

// Vtable
struct _jc_javax_rmi_CORBA_Stub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_CORBA_ObjectImpl$vmethods	javax_rmi_CORBA_ObjectImpl;
	_jc_javax_rmi_CORBA_Stub$vmethods	javax_rmi_CORBA_Stub;
};

// Vtype
struct _jc_javax_rmi_CORBA_Stub$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_Stub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_Stub$sub_refs {
	struct _jc_object	*delegate;
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_Stub$refs {
    _jc_javax_rmi_CORBA_Stub$sub_refs	javax_rmi_CORBA_Stub;
    _jc_javax_rmi_CORBA_ObjectImpl$sub_refs	javax_rmi_CORBA_ObjectImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_Stub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_Stub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs	javax_rmi_CORBA_ObjectImpl;
    _jc_javax_rmi_CORBA_Stub$sub_nonrefs	javax_rmi_CORBA_Stub;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_Stub$object {
	_jc_javax_rmi_CORBA_Stub$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_Stub$vtype	*vtype;
	_jc_javax_rmi_CORBA_Stub$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_Stub$vtype _jc_javax_rmi_CORBA_Stub$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_Stub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_Stub$class_object;

#endif	/* _JC_javax_rmi_CORBA_Stub_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/CORBA/Stub.h <==
// public abstract class javax.rmi.CORBA.Stub

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5219dfd5835e78ba javax_rmi_CORBA_ObjectImpl
// @dep_class cc968e93a57cbcb6 javax_rmi_CORBA_Stub

// header file dependencies
// @dep_header javax_rmi_CORBA_ObjectImpl

#include "javax/rmi/CORBA/ObjectImpl.h"

#ifndef _JC_javax_rmi_CORBA_Stub_H_
#define _JC_javax_rmi_CORBA_Stub_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_rmi_CORBA_StubDelegate$object;
struct _jc_javax_rmi_ORB$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_Stub$sub_refs	_jc_javax_rmi_CORBA_Stub$sub_refs;
typedef struct _jc_javax_rmi_CORBA_Stub$sub_nonrefs	_jc_javax_rmi_CORBA_Stub$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_Stub$refs	_jc_javax_rmi_CORBA_Stub$refs;
typedef struct _jc_javax_rmi_CORBA_Stub$nonrefs	_jc_javax_rmi_CORBA_Stub$nonrefs;
typedef struct _jc_javax_rmi_CORBA_Stub$object	_jc_javax_rmi_CORBA_Stub$object;

typedef struct _jc_javax_rmi_CORBA_Stub$fields_struct	_jc_javax_rmi_CORBA_Stub$fields_struct;
typedef const struct _jc_javax_rmi_CORBA_Stub$vmethods	_jc_javax_rmi_CORBA_Stub$vmethods;
typedef const struct _jc_javax_rmi_CORBA_Stub$vtable	_jc_javax_rmi_CORBA_Stub$vtable;
typedef const struct _jc_javax_rmi_CORBA_Stub$vtype	_jc_javax_rmi_CORBA_Stub$vtype;

// Class fields structure
struct _jc_javax_rmi_CORBA_Stub$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_rmi_CORBA_Stub$fields_struct _jc_javax_rmi_CORBA_Stub$class_fields;

// Constructors
extern void _jc_javax_rmi_CORBA_Stub$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_rmi_CORBA_Stub$method$connect$841f9bfd39e4d76b(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_javax_rmi_ORB$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_rmi_CORBA_Stub$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_rmi_CORBA_Stub$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *) _JC_JCNI_ATTR;
extern void _jc_javax_rmi_CORBA_Stub$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_rmi_CORBA_Stub$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *) _JC_JCNI_ATTR;
extern void _jc_javax_rmi_CORBA_Stub$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$connect$841f9bfd39e4d76b;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_javax_rmi_CORBA_Stub$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_javax_rmi_CORBA_Stub$vmethods {
	void	(*connect$841f9bfd39e4d76b)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_javax_rmi_ORB$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *) _JC_JCNI_ATTR;
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *) _JC_JCNI_ATTR;
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_javax_rmi_CORBA_Stub$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_rmi_CORBA_Stub$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_CORBA_ObjectImpl$vmethods	javax_rmi_CORBA_ObjectImpl;
	_jc_javax_rmi_CORBA_Stub$vmethods	javax_rmi_CORBA_Stub;
};

// Vtype
struct _jc_javax_rmi_CORBA_Stub$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_Stub$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_Stub$sub_refs {
	struct _jc_object	*delegate;
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_Stub$refs {
    _jc_javax_rmi_CORBA_Stub$sub_refs	javax_rmi_CORBA_Stub;
    _jc_javax_rmi_CORBA_ObjectImpl$sub_refs	javax_rmi_CORBA_ObjectImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_Stub$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_Stub$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs	javax_rmi_CORBA_ObjectImpl;
    _jc_javax_rmi_CORBA_Stub$sub_nonrefs	javax_rmi_CORBA_Stub;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_Stub$object {
	_jc_javax_rmi_CORBA_Stub$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_Stub$vtype	*vtype;
	_jc_javax_rmi_CORBA_Stub$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_Stub$vtype _jc_javax_rmi_CORBA_Stub$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_Stub, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_Stub$class_object;

#endif	/* _JC_javax_rmi_CORBA_Stub_H_ */
